@@ -1,7 +1,11 @@
 def _disable_linecache():
     import linecache
-    def fake_getline(filename, lineno):
+
+    def fake_getline(*args, **kwargs):
         return ''
+
     linecache.orig_getline = linecache.getline
     linecache.getline = fake_getline
+
+
 _disable_linecache()
